[Libreoffice-commits] core.git: 7 commits - sw/source
Jan Holesovsky
kendy at collabora.com
Tue May 12 02:17:07 PDT 2015
sw/source/core/doc/htmltbl.cxx | 4
sw/source/core/docnode/ndcopy.cxx | 77 +++++++++---------
sw/source/core/docnode/ndtbl1.cxx | 28 +++---
sw/source/core/edit/acorrect.cxx | 16 +--
sw/source/core/fields/reffld.cxx | 6 -
sw/source/core/inc/acorrect.hxx | 28 +++---
sw/source/core/inc/txmsrt.hxx | 6 -
sw/source/ui/fldui/fldpage.cxx | 2
sw/source/uibase/fldui/fldmgr.cxx | 148 ++++++++++++++++++------------------
sw/source/uibase/inc/fldmgr.hxx | 49 +++++------
sw/source/uibase/shells/textsh2.cxx | 4
11 files changed, 185 insertions(+), 183 deletions(-)
New commits:
commit 443d5205d22aa952f8b6975a96ffe8dc0e24d409
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 11:15:13 2015 +0200
sw: Rename a variable.
Change-Id: I1b026273942d325eefdd53f0268e5ca5505ede04
diff --git a/sw/source/core/fields/reffld.cxx b/sw/source/core/fields/reffld.cxx
index 6ea05f5..f75eedf 100644
--- a/sw/source/core/fields/reffld.cxx
+++ b/sw/source/core/fields/reffld.cxx
@@ -288,13 +288,13 @@ void SwGetRefField::UpdateField( const SwTxtFld* pFldTxtAttr )
return ;
}
// where is the category name (e.g. "Illustration")?
- OUString const sText = pTxtNd->GetTxt();
- const sal_Int32 nCatStart = sText.indexOf(sSetRefName);
+ const OUString aText = pTxtNd->GetTxt();
+ const sal_Int32 nCatStart = aText.indexOf(sSetRefName);
const bool bHasCat = nCatStart>=0;
const sal_Int32 nCatEnd = bHasCat ? nCatStart + sSetRefName.getLength() : -1;
// length of the referenced text
- const sal_Int32 nLen = sText.getLength();
+ const sal_Int32 nLen = aText.getLength();
// which format?
switch( GetFormat() )
commit fe036ea3fa0cd594e65f99d9c2ff07c8623e5f5e
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 11:11:27 2015 +0200
sw: Prefix LinesAndTable member variables.
Change-Id: Ic5c8e439de38a421e2ac056fc1c11c872cee34f7
diff --git a/sw/source/core/docnode/ndtbl1.cxx b/sw/source/core/docnode/ndtbl1.cxx
index fe857d4..3411323 100644
--- a/sw/source/core/docnode/ndtbl1.cxx
+++ b/sw/source/core/docnode/ndtbl1.cxx
@@ -164,12 +164,12 @@ static bool lcl_IsAnLower( const SwTableLine *pLine, const SwTableLine *pAssumed
struct LinesAndTable
{
- std::vector<SwTableLine*> &rLines;
- const SwTable &rTable;
- bool bInsertLines;
+ std::vector<SwTableLine*> &m_rLines;
+ const SwTable &m_rTable;
+ bool m_bInsertLines;
- LinesAndTable( std::vector<SwTableLine*> &rL, const SwTable &rTbl ) :
- rLines( rL ), rTable( rTbl ), bInsertLines( true ) {}
+ LinesAndTable(std::vector<SwTableLine*> &rL, const SwTable &rTbl) :
+ m_rLines(rL), m_rTable(rTbl), m_bInsertLines(true) {}
};
bool _FindLine( _FndLine & rLine, LinesAndTable* pPara );
@@ -178,27 +178,27 @@ bool _FindBox( _FndBox & rBox, LinesAndTable* pPara )
{
if (!rBox.GetLines().empty())
{
- pPara->bInsertLines = true;
- for( _FndLine & rFndLine : rBox.GetLines() )
- _FindLine( rFndLine, pPara );
- if ( pPara->bInsertLines )
+ pPara->m_bInsertLines = true;
+ for (_FndLine & rFndLine : rBox.GetLines())
+ _FindLine(rFndLine, pPara);
+
+ if (pPara->m_bInsertLines)
{
const SwTableLines &rLines = (rBox.GetBox())
? rBox.GetBox()->GetTabLines()
- : pPara->rTable.GetTabLines();
+ : pPara->m_rTable.GetTabLines();
if (rBox.GetLines().size() == rLines.size())
{
for ( auto pLine : rLines )
- ::InsertLine( pPara->rLines, pLine );
+ ::InsertLine(pPara->m_rLines, pLine);
}
else
- pPara->bInsertLines = false;
+ pPara->m_bInsertLines = false;
}
}
else if (rBox.GetBox())
{
- ::InsertLine( pPara->rLines,
- static_cast<SwTableLine*>(rBox.GetBox()->GetUpper()));
+ ::InsertLine(pPara->m_rLines, static_cast<SwTableLine*>(rBox.GetBox()->GetUpper()));
}
return true;
}
commit 6a298f0ef5e2de59cf42decd01cb25230c960f75
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 11:05:48 2015 +0200
sw: Prefix _CopyTable member variables.
Change-Id: I12a020f4912921761a8bc4f8913638b5b41a91b5
diff --git a/sw/source/core/docnode/ndcopy.cxx b/sw/source/core/docnode/ndcopy.cxx
index 0dd84b4..21dd4b9 100644
--- a/sw/source/core/docnode/ndcopy.cxx
+++ b/sw/source/core/docnode/ndcopy.cxx
@@ -120,18 +120,18 @@ static bool lcl_SrchNew( const _MapTblFrmFmt& rMap, SwFrmFmt** pPara )
struct _CopyTable
{
- SwDoc* pDoc;
- sal_uLong nOldTblSttIdx;
- _MapTblFrmFmts& rMapArr;
- SwTableLine* pInsLine;
- SwTableBox* pInsBox;
- SwTableNode *pTblNd;
- const SwTable *pOldTable;
-
- _CopyTable( SwDoc* pDc, _MapTblFrmFmts& rArr, sal_uLong nOldStt,
- SwTableNode& rTblNd, const SwTable* pOldTbl )
- : pDoc(pDc), nOldTblSttIdx(nOldStt), rMapArr(rArr),
- pInsLine(0), pInsBox(0), pTblNd(&rTblNd), pOldTable( pOldTbl )
+ SwDoc* m_pDoc;
+ sal_uLong m_nOldTblSttIdx;
+ _MapTblFrmFmts& m_rMapArr;
+ SwTableLine* m_pInsLine;
+ SwTableBox* m_pInsBox;
+ SwTableNode *m_pTblNd;
+ const SwTable *m_pOldTable;
+
+ _CopyTable(SwDoc* pDc, _MapTblFrmFmts& rArr, sal_uLong nOldStt,
+ SwTableNode& rTblNd, const SwTable* pOldTable)
+ : m_pDoc(pDc), m_nOldTblSttIdx(nOldStt), m_rMapArr(rArr),
+ m_pInsLine(0), m_pInsBox(0), m_pTblNd(&rTblNd), m_pOldTable(pOldTable)
{}
};
@@ -140,24 +140,25 @@ static void lcl_CopyTblLine( const SwTableLine* pLine, _CopyTable* pCT );
static void lcl_CopyTblBox( SwTableBox* pBox, _CopyTable* pCT )
{
SwTableBoxFmt * pBoxFmt = static_cast<SwTableBoxFmt*>(pBox->GetFrmFmt());
- for( _MapTblFrmFmts::const_iterator it = pCT->rMapArr.begin(); it != pCT->rMapArr.end(); ++it )
+ for (_MapTblFrmFmts::const_iterator it = pCT->m_rMapArr.begin(); it != pCT->m_rMapArr.end(); ++it)
if ( !lcl_SrchNew( *it, reinterpret_cast<SwFrmFmt**>(&pBoxFmt) ) )
break;
- if( pBoxFmt == pBox->GetFrmFmt() ) // Create a new one?
+
+ if (pBoxFmt == pBox->GetFrmFmt()) // Create a new one?
{
const SfxPoolItem* pItem;
if( SfxItemState::SET == pBoxFmt->GetItemState( RES_BOXATR_FORMULA, false,
&pItem ) && static_cast<const SwTblBoxFormula*>(pItem)->IsIntrnlName() )
{
- const_cast<SwTblBoxFormula*>(static_cast<const SwTblBoxFormula*>(pItem))->PtrToBoxNm( pCT->pOldTable );
+ const_cast<SwTblBoxFormula*>(static_cast<const SwTblBoxFormula*>(pItem))->PtrToBoxNm(pCT->m_pOldTable);
}
- pBoxFmt = pCT->pDoc->MakeTableBoxFmt();
+ pBoxFmt = pCT->m_pDoc->MakeTableBoxFmt();
pBoxFmt->CopyAttrs( *pBox->GetFrmFmt() );
if( pBox->GetSttIdx() )
{
- SvNumberFormatter* pN = pCT->pDoc->GetNumberFormatter( false );
+ SvNumberFormatter* pN = pCT->m_pDoc->GetNumberFormatter(false);
if( pN && pN->HasMergeFmtTbl() && SfxItemState::SET == pBoxFmt->
GetItemState( RES_BOXATR_FORMAT, false, &pItem ) )
{
@@ -169,60 +170,64 @@ static void lcl_CopyTblBox( SwTableBox* pBox, _CopyTable* pCT )
}
}
- pCT->rMapArr.push_back( _MapTblFrmFmt( pBox->GetFrmFmt(), pBoxFmt ) );
+ pCT->m_rMapArr.push_back(_MapTblFrmFmt(pBox->GetFrmFmt(), pBoxFmt));
}
sal_uInt16 nLines = pBox->GetTabLines().size();
SwTableBox* pNewBox;
if( nLines )
- pNewBox = new SwTableBox( pBoxFmt, nLines, pCT->pInsLine );
+ pNewBox = new SwTableBox(pBoxFmt, nLines, pCT->m_pInsLine);
else
{
- SwNodeIndex aNewIdx( *pCT->pTblNd,
- pBox->GetSttIdx() - pCT->nOldTblSttIdx );
+ SwNodeIndex aNewIdx(*pCT->m_pTblNd, pBox->GetSttIdx() - pCT->m_nOldTblSttIdx);
OSL_ENSURE( aNewIdx.GetNode().IsStartNode(), "Index is not on the start node" );
- pNewBox = new SwTableBox( pBoxFmt, aNewIdx, pCT->pInsLine );
+
+ pNewBox = new SwTableBox(pBoxFmt, aNewIdx, pCT->m_pInsLine);
pNewBox->setRowSpan( pBox->getRowSpan() );
}
- pCT->pInsLine->GetTabBoxes().push_back( pNewBox );
+ pCT->m_pInsLine->GetTabBoxes().push_back( pNewBox );
- if( nLines )
+ if (nLines)
{
- _CopyTable aPara( *pCT );
- aPara.pInsBox = pNewBox;
+ _CopyTable aPara(*pCT);
+ aPara.m_pInsBox = pNewBox;
for( const SwTableLine* pLine : pBox->GetTabLines() )
lcl_CopyTblLine( pLine, &aPara );
}
- else if( pNewBox->IsInHeadline( &pCT->pTblNd->GetTable() ))
+ else if (pNewBox->IsInHeadline(&pCT->m_pTblNd->GetTable()))
+ {
// In the headline, the paragraphs must match conditional styles
pNewBox->GetSttNd()->CheckSectionCondColl();
+ }
}
static void lcl_CopyTblLine( const SwTableLine* pLine, _CopyTable* pCT )
{
SwTableLineFmt * pLineFmt = static_cast<SwTableLineFmt*>(pLine->GetFrmFmt());
- for( _MapTblFrmFmts::const_iterator it = pCT->rMapArr.begin(); it != pCT->rMapArr.end(); ++it )
+ for (_MapTblFrmFmts::const_iterator it = pCT->m_rMapArr.begin(); it != pCT->m_rMapArr.end(); ++it)
if ( !lcl_SrchNew( *it, reinterpret_cast<SwFrmFmt**>(&pLineFmt) ) )
break;
+
if( pLineFmt == pLine->GetFrmFmt() ) // Create a new one?
{
- pLineFmt = pCT->pDoc->MakeTableLineFmt();
+ pLineFmt = pCT->m_pDoc->MakeTableLineFmt();
pLineFmt->CopyAttrs( *pLine->GetFrmFmt() );
- pCT->rMapArr.push_back( _MapTblFrmFmt( pLine->GetFrmFmt(), pLineFmt ) );
+ pCT->m_rMapArr.push_back(_MapTblFrmFmt(pLine->GetFrmFmt(), pLineFmt));
}
- SwTableLine* pNewLine = new SwTableLine( pLineFmt,
- pLine->GetTabBoxes().size(), pCT->pInsBox );
+
+ SwTableLine* pNewLine = new SwTableLine(pLineFmt, pLine->GetTabBoxes().size(), pCT->m_pInsBox);
// Insert the new row into the table
- if( pCT->pInsBox )
+ if (pCT->m_pInsBox)
{
- pCT->pInsBox->GetTabLines().push_back( pNewLine );
+ pCT->m_pInsBox->GetTabLines().push_back(pNewLine);
}
else
{
- pCT->pTblNd->GetTable().GetTabLines().push_back( pNewLine );
+ pCT->m_pTblNd->GetTable().GetTabLines().push_back(pNewLine);
}
- pCT->pInsLine = pNewLine;
+
+ pCT->m_pInsLine = pNewLine;
for( SwTableBoxes::iterator it = const_cast<SwTableLine*>(pLine)->GetTabBoxes().begin();
it != const_cast<SwTableLine*>(pLine)->GetTabBoxes().end(); ++it)
lcl_CopyTblBox(*it, pCT );
commit 0571a2de45b1803bcd930224d9579f4a3a6f43d7
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 10:55:15 2015 +0200
sw: Change variable name.
Change-Id: I3721174723eeff4a5a02bd40c3d037da2c3f5a5d
diff --git a/sw/source/core/doc/htmltbl.cxx b/sw/source/core/doc/htmltbl.cxx
index 1af1548..b88f026 100644
--- a/sw/source/core/doc/htmltbl.cxx
+++ b/sw/source/core/doc/htmltbl.cxx
@@ -168,7 +168,7 @@ SwHTMLTableLayoutConstraints *SwHTMLTableLayoutConstraints::InsertNext(
typedef SwHTMLTableLayoutColumn *SwHTMLTableLayoutColumnPtr;
typedef SwHTMLTableLayoutCell *SwHTMLTableLayoutCellPtr;
-SwHTMLTableLayout::SwHTMLTableLayout( const SwTable * pSwTbl,
+SwHTMLTableLayout::SwHTMLTableLayout( const SwTable * pTable,
sal_uInt16 nRws, sal_uInt16 nCls,
bool bColsOpt, bool bColTgs,
sal_uInt16 nWdth, bool bPrcWdth,
@@ -181,7 +181,7 @@ SwHTMLTableLayout::SwHTMLTableLayout( const SwTable * pSwTbl,
sal_uInt16 nInhRightBWidth )
: aColumns( new SwHTMLTableLayoutColumnPtr[nCls] )
, aCells( new SwHTMLTableLayoutCellPtr[static_cast<size_t>(nRws)*nCls] )
- , pSwTable( pSwTbl )
+ , pSwTable( pTable )
, pLeftFillerBox( 0 )
, pRightFillerBox( 0 )
, nMin( 0 )
commit ffae8ac2411bd1bae2e1299128100ed7fcf85108
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 10:53:33 2015 +0200
sw: Prefix SwAutoCorrExceptWord member variables.
Change-Id: I2849aafc407e4fd0a24ea3d98043c399a9414ffe
diff --git a/sw/source/core/edit/acorrect.cxx b/sw/source/core/edit/acorrect.cxx
index eb877fb..c986957 100644
--- a/sw/source/core/edit/acorrect.cxx
+++ b/sw/source/core/edit/acorrect.cxx
@@ -432,26 +432,24 @@ void SwAutoCorrExceptWord::CheckChar( const SwPosition& rPos, sal_Unicode cChr )
{
// test only if this is a improvement.
// If yes, then add the word to the list.
- if( cChar == cChr && rPos.nNode.GetIndex() == nNode &&
- rPos.nContent.GetIndex() == nCntnt )
+ if (m_cChar == cChr && rPos.nNode.GetIndex() == m_nNode && rPos.nContent.GetIndex() == m_nContent)
{
// get the current autocorrection:
SvxAutoCorrect* pACorr = SvxAutoCorrCfg::Get().GetAutoCorrect();
// then add to the list:
- if( CptlSttWrd & nFlags )
- pACorr->AddWrtSttException( sWord, eLanguage );
- else if( CptlSttSntnc & nFlags )
- pACorr->AddCplSttException( sWord, eLanguage );
+ if (CptlSttWrd & m_nFlags)
+ pACorr->AddWrtSttException(m_sWord, m_eLanguage);
+ else if (CptlSttSntnc & m_nFlags)
+ pACorr->AddCplSttException(m_sWord, m_eLanguage);
}
}
bool SwAutoCorrExceptWord::CheckDelChar( const SwPosition& rPos )
{
bool bRet = false;
- if( !bDeleted && rPos.nNode.GetIndex() == nNode &&
- rPos.nContent.GetIndex() == nCntnt )
- bDeleted = bRet = true;
+ if (!m_bDeleted && rPos.nNode.GetIndex() == m_nNode && rPos.nContent.GetIndex() == m_nContent)
+ m_bDeleted = bRet = true;
return bRet;
}
diff --git a/sw/source/core/inc/acorrect.hxx b/sw/source/core/inc/acorrect.hxx
index 713cfd7..47870f0 100644
--- a/sw/source/core/inc/acorrect.hxx
+++ b/sw/source/core/inc/acorrect.hxx
@@ -89,24 +89,24 @@ public:
class SwAutoCorrExceptWord
{
- OUString sWord;
- sal_uLong nFlags, nNode;
- sal_Int32 nCntnt;
- sal_Unicode cChar;
- LanguageType eLanguage;
- bool bDeleted;
+ OUString m_sWord;
+ sal_uLong m_nFlags, m_nNode;
+ sal_Int32 m_nContent;
+ sal_Unicode m_cChar;
+ LanguageType m_eLanguage;
+ bool m_bDeleted;
public:
- SwAutoCorrExceptWord( sal_uLong nAFlags, sal_uLong nNd, sal_Int32 nContent,
- const OUString& rWord, sal_Unicode cChr,
- LanguageType eLang )
- : sWord(rWord), nFlags(nAFlags), nNode(nNd), nCntnt(nContent),
- cChar(cChr), eLanguage(eLang), bDeleted(false)
+ SwAutoCorrExceptWord(sal_uLong nAFlags, sal_uLong nNd, sal_Int32 nContent,
+ const OUString& rWord, sal_Unicode cChr,
+ LanguageType eLang)
+ : m_sWord(rWord), m_nFlags(nAFlags), m_nNode(nNd), m_nContent(nContent),
+ m_cChar(cChr), m_eLanguage(eLang), m_bDeleted(false)
{}
- bool IsDeleted() const { return bDeleted; }
- void CheckChar( const SwPosition& rPos, sal_Unicode cChar );
- bool CheckDelChar( const SwPosition& rPos );
+ bool IsDeleted() const { return m_bDeleted; }
+ void CheckChar(const SwPosition& rPos, sal_Unicode cChar);
+ bool CheckDelChar(const SwPosition& rPos);
};
#endif
commit 70c4355ffd494dffb59818c225b4a3343476e9a6
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 10:39:57 2015 +0200
sw: Prefix SwInsertFld_Data member variables.
Change-Id: I2c07a57e60f8eaf1b9d570f4d42dd2955574a85b
diff --git a/sw/source/ui/fldui/fldpage.cxx b/sw/source/ui/fldui/fldpage.cxx
index a8d2b4a..20b6651 100644
--- a/sw/source/ui/fldui/fldpage.cxx
+++ b/sw/source/ui/fldui/fldpage.cxx
@@ -127,7 +127,7 @@ bool SwFldPage::InsertFld(sal_uInt16 nTypeId, sal_uInt16 nSubType, const OUStrin
{
SwInsertFld_Data aData(nTypeId, nSubType, rPar1, rPar2, nFormatId, 0, cSeparator, bIsAutomaticLanguage );
//#i26566# provide parent for SwWrtShell::StartInputFldDlg
- aData.pParent = &GetTabDialog()->GetOKButton();
+ aData.m_pParent = &GetTabDialog()->GetOKButton();
bRet = m_aMgr.InsertFld( aData );
uno::Reference< frame::XDispatchRecorder > xRecorder =
diff --git a/sw/source/uibase/inc/fldmgr.hxx b/sw/source/uibase/inc/fldmgr.hxx
index 24b1d16..3fc3a3c 100644
--- a/sw/source/uibase/inc/fldmgr.hxx
+++ b/sw/source/uibase/inc/fldmgr.hxx
@@ -65,36 +65,35 @@ struct SwFldGroupRgn
// with command strings
struct SwInsertFld_Data
{
- sal_uInt16 nTypeId;
- sal_uInt16 nSubType;
- const OUString sPar1;
- const OUString sPar2;
- sal_uLong nFormatId;
- SwWrtShell* pSh;
- sal_Unicode cSeparator;
- bool bIsAutomaticLanguage;
- ::com::sun::star::uno::Any aDBDataSource;
- ::com::sun::star::uno::Any aDBConnection;
- ::com::sun::star::uno::Any aDBColumn;
- VclPtr<vcl::Window> pParent; // parent dialog used for SwWrtShell::StartInputFldDlg()
+ sal_uInt16 m_nTypeId;
+ sal_uInt16 m_nSubType;
+ const OUString m_sPar1;
+ const OUString m_sPar2;
+ sal_uLong m_nFormatId;
+ SwWrtShell* m_pSh;
+ sal_Unicode m_cSeparator;
+ bool m_bIsAutomaticLanguage;
+ ::com::sun::star::uno::Any m_aDBDataSource;
+ ::com::sun::star::uno::Any m_aDBConnection;
+ ::com::sun::star::uno::Any m_aDBColumn;
+ VclPtr<vcl::Window> m_pParent; // parent dialog used for SwWrtShell::StartInputFldDlg()
SwInsertFld_Data(sal_uInt16 nType, sal_uInt16 nSub, const OUString& rPar1, const OUString& rPar2,
sal_uLong nFmtId, SwWrtShell* pShell = NULL, sal_Unicode cSep = ' ', bool bIsAutoLanguage = true) :
- nTypeId(nType),
- nSubType(nSub),
- sPar1(rPar1),
- sPar2(rPar2),
- nFormatId(nFmtId),
- pSh(pShell),
- cSeparator(cSep),
- bIsAutomaticLanguage(bIsAutoLanguage),
- pParent(0) {}
+ m_nTypeId(nType),
+ m_nSubType(nSub),
+ m_sPar1(rPar1),
+ m_sPar2(rPar2),
+ m_nFormatId(nFmtId),
+ m_pSh(pShell),
+ m_cSeparator(cSep),
+ m_bIsAutomaticLanguage(bIsAutoLanguage),
+ m_pParent(0) {}
SwInsertFld_Data() :
- pSh(0),
- cSeparator(' '),
- bIsAutomaticLanguage(true){}
-
+ m_pSh(0),
+ m_cSeparator(' '),
+ m_bIsAutomaticLanguage(true){}
};
class SW_DLLPUBLIC SwFldMgr
diff --git a/sw/source/uibase/shells/textsh2.cxx b/sw/source/uibase/shells/textsh2.cxx
index 1716954..a36f8f3 100644
--- a/sw/source/uibase/shells/textsh2.cxx
+++ b/sw/source/uibase/shells/textsh2.cxx
@@ -208,9 +208,9 @@ void SwTextShell::ExecDB(SfxRequest &rReq)
SwFldMgr aFldMgr(GetShellPtr());
SwInsertFld_Data aData(TYP_DBFLD, 0, sDBName, OUString(), 0);
if(pConnectionItem)
- aData.aDBConnection = static_cast<const SfxUsrAnyItem*>(pConnectionItem)->GetValue();
+ aData.m_aDBConnection = static_cast<const SfxUsrAnyItem*>(pConnectionItem)->GetValue();
if(pColumnItem)
- aData.aDBColumn = static_cast<const SfxUsrAnyItem*>(pColumnItem)->GetValue();
+ aData.m_aDBColumn = static_cast<const SfxUsrAnyItem*>(pColumnItem)->GetValue();
aFldMgr.InsertFld(aData);
SfxViewFrame* pViewFrame = GetView().GetViewFrame();
uno::Reference< XDispatchRecorder > xRecorder =
commit 2feddc10430ee932df0414406d7200b57f50d632
Author: Jan Holesovsky <kendy at collabora.com>
Date: Tue May 12 10:39:34 2015 +0200
sw: Better variable name.
Change-Id: Id02f9bb3ba2d1530c842446d63138234b82d3f97
diff --git a/sw/source/core/inc/txmsrt.hxx b/sw/source/core/inc/txmsrt.hxx
index aa25f2e..8822a21 100644
--- a/sw/source/core/inc/txmsrt.hxx
+++ b/sw/source/core/inc/txmsrt.hxx
@@ -63,9 +63,9 @@ struct TextAndReading
TextAndReading() {}
- TextAndReading(const OUString& sTxt, const OUString& sRdng)
- : sText(sTxt)
- , sReading(sRdng)
+ TextAndReading(const OUString& rText, const OUString& rReading)
+ : sText(rText)
+ , sReading(rReading)
{}
};
More information about the Libreoffice-commits
mailing list
diff --git a/sw/source/uibase/fldui/fldmgr.cxx b/sw/source/uibase/fldui/fldmgr.cxx
index 1be211b..5a1d5e4 100644
--- a/sw/source/uibase/fldui/fldmgr.cxx
+++ b/sw/source/uibase/fldui/fldmgr.cxx
@@ -759,17 +759,17 @@ bool SwFldMgr::InsertFld(
bool bExp = false;
bool bTbl = false;
bool bPageVar = false;
- sal_uLong nFormatId = rData.nFormatId;
- sal_uInt16 nSubType = rData.nSubType;
- sal_Unicode cSeparator = rData.cSeparator;
- SwWrtShell* pCurShell = rData.pSh;
+ sal_uLong nFormatId = rData.m_nFormatId;
+ sal_uInt16 nSubType = rData.m_nSubType;
+ sal_Unicode cSeparator = rData.m_cSeparator;
+ SwWrtShell* pCurShell = rData.m_pSh;
if(!pCurShell)
pCurShell = pWrtShell ? pWrtShell : ::lcl_GetShell();
OSL_ENSURE(pCurShell, "no SwWrtShell found");
if(!pCurShell)
return false;
- switch(rData.nTypeId)
+ switch (rData.m_nTypeId)
{ // ATTENTION this field is inserted by a separate dialog
case TYP_POSTITFLD:
{
@@ -777,8 +777,8 @@ bool SwFldMgr::InsertFld(
SwPostItField* pPostItField =
new SwPostItField(
pType,
- rData.sPar1, // author
- rData.sPar2, // content
+ rData.m_sPar1, // author
+ rData.m_sPar2, // content
OUString(), // author's initials
OUString(), // name
DateTime(DateTime::SYSTEM) );
@@ -789,7 +789,7 @@ bool SwFldMgr::InsertFld(
{
SwScriptFieldType* pType =
static_cast<SwScriptFieldType*>(pCurShell->GetFldType(0, RES_SCRIPTFLD));
- pFld = new SwScriptField(pType, rData.sPar1, rData.sPar2, (bool)nFormatId);
+ pFld = new SwScriptField(pType, rData.m_sPar1, rData.m_sPar2, (bool)nFormatId);
break;
}
@@ -797,7 +797,7 @@ bool SwFldMgr::InsertFld(
{
SwCombinedCharFieldType* pType = static_cast<SwCombinedCharFieldType*>(
pCurShell->GetFldType( 0, RES_COMBINED_CHARS ));
- pFld = new SwCombinedCharField( pType, rData.sPar1 );
+ pFld = new SwCombinedCharField( pType, rData.m_sPar1 );
}
break;
@@ -811,20 +811,20 @@ bool SwFldMgr::InsertFld(
pType = static_cast<SwAuthorityFieldType*>(
pCurShell->InsertFldType(type));
}
- pFld = new SwAuthorityField(pType, rData.sPar1);
+ pFld = new SwAuthorityField(pType, rData.m_sPar1);
}
break;
case TYP_DATEFLD:
case TYP_TIMEFLD:
{
- sal_uInt16 nSub = static_cast< sal_uInt16 >(rData.nTypeId == TYP_DATEFLD ? DATEFLD : TIMEFLD);
+ sal_uInt16 nSub = static_cast< sal_uInt16 >(rData.m_nTypeId == TYP_DATEFLD ? DATEFLD : TIMEFLD);
nSub |= nSubType == DATE_VAR ? 0 : FIXEDFLD;
SwDateTimeFieldType* pTyp =
static_cast<SwDateTimeFieldType*>( pCurShell->GetFldType(0, RES_DATETIMEFLD) );
pFld = new SwDateTimeField(pTyp, nSub, nFormatId);
- pFld->SetPar2(rData.sPar2);
+ pFld->SetPar2(rData.m_sPar2);
break;
}
@@ -846,7 +846,7 @@ bool SwFldMgr::InsertFld(
case TYP_CHAPTERFLD:
{
- sal_uInt16 nByte = (sal_uInt16)rData.sPar2.toInt32();
+ sal_uInt16 nByte = (sal_uInt16)rData.m_sPar2.toInt32();
SwChapterFieldType* pTyp =
static_cast<SwChapterFieldType*>( pCurShell->GetFldType(0, RES_CHAPTERFLD) );
pFld = new SwChapterField(pTyp, nFormatId);
@@ -861,9 +861,9 @@ bool SwFldMgr::InsertFld(
case TYP_PREVPAGEFLD:
case TYP_PAGENUMBERFLD:
{
- short nOff = (short)rData.sPar2.toInt32();
+ short nOff = (short)rData.m_sPar2.toInt32();
- if(rData.nTypeId == TYP_NEXTPAGEFLD)
+ if(rData.m_nTypeId == TYP_NEXTPAGEFLD)
{
if( SVX_NUM_CHAR_SPECIAL == nFormatId )
nOff = 1;
@@ -871,7 +871,7 @@ bool SwFldMgr::InsertFld(
nOff += 1;
nSubType = PG_NEXT;
}
- else if(rData.nTypeId == TYP_PREVPAGEFLD)
+ else if(rData.m_nTypeId == TYP_PREVPAGEFLD)
{
if( SVX_NUM_CHAR_SPECIAL == nFormatId )
nOff = -1;
@@ -888,7 +888,7 @@ bool SwFldMgr::InsertFld(
if( SVX_NUM_CHAR_SPECIAL == nFormatId &&
( PG_PREV == nSubType || PG_NEXT == nSubType ) )
- static_cast<SwPageNumberField*>(pFld)->SetUserString( rData.sPar2 );
+ static_cast<SwPageNumberField*>(pFld)->SetUserString( rData.m_sPar2 );
break;
}
@@ -913,7 +913,7 @@ bool SwFldMgr::InsertFld(
{
SwHiddenTxtFieldType* pTyp =
static_cast<SwHiddenTxtFieldType*>( pCurShell->GetFldType(0, RES_HIDDENTXTFLD) );
- pFld = new SwHiddenTxtField(pTyp, true, rData.sPar1, rData.sPar2, false, rData.nTypeId);
+ pFld = new SwHiddenTxtField(pTyp, true, rData.m_sPar1, rData.m_sPar2, false, rData.m_nTypeId);
bExp = true;
break;
}
@@ -922,16 +922,16 @@ bool SwFldMgr::InsertFld(
{
SwHiddenParaFieldType* pTyp =
static_cast<SwHiddenParaFieldType*>( pCurShell->GetFldType(0, RES_HIDDENPARAFLD) );
- pFld = new SwHiddenParaField(pTyp, rData.sPar1);
+ pFld = new SwHiddenParaField(pTyp, rData.m_sPar1);
bExp = true;
break;
}
case TYP_SETREFFLD:
{
- if( !rData.sPar1.isEmpty() && CanInsertRefMark( rData.sPar1 ) )
+ if( !rData.m_sPar1.isEmpty() && CanInsertRefMark( rData.m_sPar1 ) )
{
- pCurShell->SetAttrItem( SwFmtRefMark( rData.sPar1 ) );
+ pCurShell->SetAttrItem( SwFmtRefMark( rData.m_sPar1 ) );
return true;
}
return false;
@@ -941,8 +941,8 @@ bool SwFldMgr::InsertFld(
{
SwGetRefFieldType* pTyp =
static_cast<SwGetRefFieldType*>( pCurShell->GetFldType(0, RES_GETREFFLD) );
- sal_uInt16 nSeqNo = (sal_uInt16)rData.sPar2.toInt32();
- pFld = new SwGetRefField(pTyp, rData.sPar1, nSubType, nSeqNo, nFormatId);
+ sal_uInt16 nSeqNo = (sal_uInt16)rData.m_sPar2.toInt32();
+ pFld = new SwGetRefField(pTyp, rData.m_sPar1, nSubType, nSeqNo, nFormatId);
bExp = true;
break;
}
@@ -952,13 +952,13 @@ bool SwFldMgr::InsertFld(
//JP 28.08.95: DDE-Topics/-Items can have blanks in their names!
// That's not yet considered here.
sal_Int32 nIndex = 0;
- OUString sCmd = rData.sPar2.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex);
+ OUString sCmd = rData.m_sPar2.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex);
if (nIndex>=0 && ++nIndex<sCmd.getLength())
{
sCmd = sCmd.replaceFirst(OUString(' '), OUString(sfx2::cTokenSeparator), &nIndex);
}
- SwDDEFieldType aType( rData.sPar1, sCmd, static_cast<SfxLinkUpdateMode>(nFormatId) );
+ SwDDEFieldType aType( rData.m_sPar1, sCmd, static_cast<SfxLinkUpdateMode>(nFormatId) );
SwDDEFieldType* pTyp = static_cast<SwDDEFieldType*>( pCurShell->InsertFldType( aType ) );
pFld = new SwDDEField( pTyp );
break;
@@ -969,17 +969,17 @@ bool SwFldMgr::InsertFld(
SwMacroFieldType* pTyp =
static_cast<SwMacroFieldType*>(pCurShell->GetFldType(0, RES_MACROFLD));
- pFld = new SwMacroField(pTyp, rData.sPar1, rData.sPar2);
+ pFld = new SwMacroField(pTyp, rData.m_sPar1, rData.m_sPar2);
break;
}
case TYP_INTERNETFLD:
{
- SwFmtINetFmt aFmt( rData.sPar1, sCurFrame );
+ SwFmtINetFmt aFmt( rData.m_sPar1, sCurFrame );
if( pMacroItem )
aFmt.SetMacroTbl( &pMacroItem->GetMacroTable() );
- return pCurShell->InsertURL( aFmt, rData.sPar2 );
+ return pCurShell->InsertURL( aFmt, rData.m_sPar2 );
}
case TYP_JUMPEDITFLD:
@@ -987,7 +987,7 @@ bool SwFldMgr::InsertFld(
SwJumpEditFieldType* pTyp =
static_cast<SwJumpEditFieldType*>(pCurShell->GetFldType(0, RES_JUMPEDITFLD));
- pFld = new SwJumpEditField(pTyp, nFormatId, rData.sPar1, rData.sPar2 );
+ pFld = new SwJumpEditField(pTyp, nFormatId, rData.m_sPar1, rData.m_sPar2);
break;
}
@@ -995,7 +995,7 @@ bool SwFldMgr::InsertFld(
{
SwDocInfoFieldType* pTyp = static_cast<SwDocInfoFieldType*>( pCurShell->GetFldType(
0, RES_DOCINFOFLD ) );
- pFld = new SwDocInfoField(pTyp, nSubType, rData.sPar1, nFormatId);
+ pFld = new SwDocInfoField(pTyp, nSubType, rData.m_sPar1, nFormatId);
break;
}
@@ -1013,17 +1013,17 @@ bool SwFldMgr::InsertFld(
SwDBData aDBData;
OUString sPar1;
- if (rData.sPar1.indexOf(DB_DELIM)<0)
+ if (rData.m_sPar1.indexOf(DB_DELIM)<0)
{
aDBData = pCurShell->GetDBData();
- sPar1 = rData.sPar1;
+ sPar1 = rData.m_sPar1;
}
else
{
- aDBData.sDataSource = rData.sPar1.getToken(0, DB_DELIM);
- aDBData.sCommand = rData.sPar1.getToken(1, DB_DELIM);
- aDBData.nCommandType = rData.sPar1.getToken(2, DB_DELIM).toInt32();
- sPar1 = rData.sPar1.getToken(3, DB_DELIM);
+ aDBData.sDataSource = rData.m_sPar1.getToken(0, DB_DELIM);
+ aDBData.sCommand = rData.m_sPar1.getToken(1, DB_DELIM);
+ aDBData.nCommandType = rData.m_sPar1.getToken(2, DB_DELIM).toInt32();
+ sPar1 = rData.m_sPar1.getToken(3, DB_DELIM);
}
if(!aDBData.sDataSource.isEmpty() && pCurShell->GetDBData() != aDBData)
@@ -1037,11 +1037,11 @@ bool SwFldMgr::InsertFld(
if( !(nSubType & nsSwExtendedSubType::SUB_OWN_FMT) ) // determinee database format
{
Reference< XDataSource> xSource;
- rData.aDBDataSource >>= xSource;
+ rData.m_aDBDataSource >>= xSource;
Reference<XConnection> xConnection;
- rData.aDBConnection >>= xConnection;
+ rData.m_aDBConnection >>= xConnection;
Reference<XPropertySet> xColumn;
- rData.aDBColumn >>= xColumn;
+ rData.m_aDBColumn >>= xColumn;
if(xColumn.is())
{
nFormatId = SwDBManager::GetColumnFmt(xSource, xConnection, xColumn,
@@ -1067,22 +1067,22 @@ bool SwFldMgr::InsertFld(
#if HAVE_FEATURE_DBCONNECTIVITY
SwDBData aDBData;
- // excract DBName from rData.sPar1. Format: DBName.TableName.CommandType.ExpStrg
- sal_Int32 nTablePos = rData.sPar1.indexOf(DB_DELIM);
+ // excract DBName from rData.m_sPar1. Format: DBName.TableName.CommandType.ExpStrg
+ sal_Int32 nTablePos = rData.m_sPar1.indexOf(DB_DELIM);
sal_Int32 nCmdTypePos = -1;
sal_Int32 nExpPos = -1;
if (nTablePos>=0)
{
- aDBData.sDataSource = rData.sPar1.copy(0, nTablePos++);
- nCmdTypePos = rData.sPar1.indexOf(DB_DELIM, nTablePos);
+ aDBData.sDataSource = rData.m_sPar1.copy(0, nTablePos++);
+ nCmdTypePos = rData.m_sPar1.indexOf(DB_DELIM, nTablePos);
if (nCmdTypePos>=0)
{
- aDBData.sCommand = rData.sPar1.copy(nTablePos, nCmdTypePos++ - nTablePos);
- nExpPos = rData.sPar1.indexOf(DB_DELIM, nCmdTypePos);
+ aDBData.sCommand = rData.m_sPar1.copy(nTablePos, nCmdTypePos++ - nTablePos);
+ nExpPos = rData.m_sPar1.indexOf(DB_DELIM, nCmdTypePos);
if (nExpPos>=0)
{
- aDBData.nCommandType = rData.sPar1.copy(nCmdTypePos, nExpPos++ - nCmdTypePos).toInt32();
+ aDBData.nCommandType = rData.m_sPar1.copy(nCmdTypePos, nExpPos++ - nCmdTypePos).toInt32();
}
}
}
@@ -1093,12 +1093,12 @@ bool SwFldMgr::InsertFld(
else if (nTablePos>=0)
nPos = nTablePos;
- OUString sPar1 = rData.sPar1.copy(nPos);
+ OUString sPar1 = rData.m_sPar1.copy(nPos);
if (!aDBData.sDataSource.isEmpty() && pCurShell->GetDBData() != aDBData)
pCurShell->ChgDBData(aDBData);
- switch(rData.nTypeId)
+ switch(rData.m_nTypeId)
{
case TYP_DBNAMEFLD:
{
@@ -1112,7 +1112,7 @@ bool SwFldMgr::InsertFld(
{
SwDBNextSetFieldType* pTyp = static_cast<SwDBNextSetFieldType*>(pCurShell->GetFldType(
0, RES_DBNEXTSETFLD) );
- pFld = new SwDBNextSetField(pTyp, sPar1, rData.sPar2, aDBData);
+ pFld = new SwDBNextSetField(pTyp, sPar1, rData.m_sPar2, aDBData);
bExp = true;
break;
}
@@ -1120,7 +1120,7 @@ bool SwFldMgr::InsertFld(
{
SwDBNumSetFieldType* pTyp = static_cast<SwDBNumSetFieldType*>( pCurShell->GetFldType(
0, RES_DBNUMSETFLD) );
- pFld = new SwDBNumSetField( pTyp, sPar1, rData.sPar2, aDBData);
+ pFld = new SwDBNumSetField( pTyp, sPar1, rData.m_sPar2, aDBData);
bExp = true;
break;
}
@@ -1140,16 +1140,16 @@ bool SwFldMgr::InsertFld(
case TYP_USERFLD:
{
SwUserFieldType* pTyp =
- static_cast<SwUserFieldType*>( pCurShell->GetFldType(RES_USERFLD, rData.sPar1) );
+ static_cast<SwUserFieldType*>( pCurShell->GetFldType(RES_USERFLD, rData.m_sPar1) );
// only if existing
if(!pTyp)
{
pTyp = static_cast<SwUserFieldType*>( pCurShell->InsertFldType(
- SwUserFieldType(pCurShell->GetDoc(), rData.sPar1)) );
+ SwUserFieldType(pCurShell->GetDoc(), rData.m_sPar1)) );
}
- if (pTyp->GetContent(nFormatId) != rData.sPar2)
- pTyp->SetContent(rData.sPar2, nFormatId);
+ if (pTyp->GetContent(nFormatId) != rData.m_sPar2)
+ pTyp->SetContent(rData.m_sPar2, nFormatId);
pFld = new SwUserField(pTyp, 0, nFormatId);
if (pFld->GetSubType() != nSubType)
pFld->SetSubType(nSubType);
@@ -1162,7 +1162,7 @@ bool SwFldMgr::InsertFld(
if ((nSubType & 0x00ff) == INP_VAR)
{
SwSetExpFieldType* pTyp = static_cast<SwSetExpFieldType*>(
- pCurShell->GetFldType(RES_SETEXPFLD, rData.sPar1) );
+ pCurShell->GetFldType(RES_SETEXPFLD, rData.m_sPar1) );
// no Experssion Type with this name existing -> create
if(pTyp)
@@ -1174,7 +1174,7 @@ bool SwFldMgr::InsertFld(
sal_uInt16 nOldSubType = pExpFld->GetSubType();
pExpFld->SetSubType(nOldSubType | (nSubType & 0xff00));
- pExpFld->SetPromptText(rData.sPar2);
+ pExpFld->SetPromptText(rData.m_sPar2);
pExpFld->SetInputFlag(true) ;
bExp = true;
pFld = pExpFld;
@@ -1188,26 +1188,26 @@ bool SwFldMgr::InsertFld(
static_cast<SwInputFieldType*>( pCurShell->GetFldType(0, RES_INPUTFLD) );
SwInputField* pInpFld =
- new SwInputField( pTyp, rData.sPar1, rData.sPar2, nSubType|nsSwExtendedSubType::SUB_INVISIBLE, nFormatId);
+ new SwInputField( pTyp, rData.m_sPar1, rData.m_sPar2, nSubType|nsSwExtendedSubType::SUB_INVISIBLE, nFormatId);
pFld = pInpFld;
}
// start dialog
- pCurShell->StartInputFldDlg(pFld, false, rData.pParent);
+ pCurShell->StartInputFldDlg(pFld, false, rData.m_pParent);
break;
}
case TYP_SETFLD:
{
- if (rData.sPar2.isEmpty()) // empty variables are not allowed
+ if (rData.m_sPar2.isEmpty()) // empty variables are not allowed
return false;
SwSetExpFieldType* pTyp = static_cast<SwSetExpFieldType*>( pCurShell->InsertFldType(
- SwSetExpFieldType(pCurShell->GetDoc(), rData.sPar1) ) );
+ SwSetExpFieldType(pCurShell->GetDoc(), rData.m_sPar1) ) );
- SwSetExpField* pExpFld = new SwSetExpField( pTyp, rData.sPar2, nFormatId);
+ SwSetExpField* pExpFld = new SwSetExpField( pTyp, rData.m_sPar2, nFormatId);
pExpFld->SetSubType(nSubType);
- pExpFld->SetPar2(rData.sPar2);
+ pExpFld->SetPar2(rData.m_sPar2);
bExp = true;
pFld = pExpFld;
break;
@@ -1216,7 +1216,7 @@ bool SwFldMgr::InsertFld(
case TYP_SEQFLD:
{
SwSetExpFieldType* pTyp = static_cast<SwSetExpFieldType*>( pCurShell->InsertFldType(
- SwSetExpFieldType(pCurShell->GetDoc(), rData.sPar1, nsSwGetSetExpType::GSE_SEQ)));
+ SwSetExpFieldType(pCurShell->GetDoc(), rData.m_sPar1, nsSwGetSetExpType::GSE_SEQ)));
sal_uInt8 nLevel = static_cast< sal_uInt8 >(nSubType & 0xff);
@@ -1225,7 +1225,7 @@ bool SwFldMgr::InsertFld(
cSeparator = '.';
pTyp->SetDelimiter(OUString(cSeparator));
- SwSetExpField* pExpFld = new SwSetExpField(pTyp, rData.sPar2, nFormatId);
+ SwSetExpField* pExpFld = new SwSetExpField(pTyp, rData.m_sPar2, nFormatId);
bExp = true;
pFld = pExpFld;
nSubType = nsSwGetSetExpType::GSE_SEQ;
@@ -1236,13 +1236,13 @@ bool SwFldMgr::InsertFld(
{
// is there a corresponding SetField
SwSetExpFieldType* pSetTyp = static_cast<SwSetExpFieldType*>(
- pCurShell->GetFldType(RES_SETEXPFLD, rData.sPar1));
+ pCurShell->GetFldType(RES_SETEXPFLD, rData.m_sPar1));
if(pSetTyp)
{
SwGetExpFieldType* pTyp = static_cast<SwGetExpFieldType*>( pCurShell->GetFldType(
0, RES_GETEXPFLD) );
- pFld = new SwGetExpField(pTyp, rData.sPar1, pSetTyp->GetType(), nFormatId);
+ pFld = new SwGetExpField(pTyp, rData.m_sPar1, pSetTyp->GetType(), nFormatId);
pFld->SetSubType(nSubType | pSetTyp->GetType());
bExp = true;
}
@@ -1270,7 +1270,7 @@ bool SwFldMgr::InsertFld(
SfxItemSet aBoxSet( pCurShell->GetAttrPool(),
RES_BOXATR_FORMULA, RES_BOXATR_FORMULA );
- OUString sFml(comphelper::string::stripStart(rData.sPar2, ' '));
+ OUString sFml(comphelper::string::stripStart(rData.m_sPar2, ' '));
if ( sFml.startsWith("=") )
{
sFml = sFml.copy(1);
@@ -1288,7 +1288,7 @@ bool SwFldMgr::InsertFld(
{
SwGetExpFieldType* pTyp = static_cast<SwGetExpFieldType*>(
pCurShell->GetFldType(0, RES_GETEXPFLD) );
- pFld = new SwGetExpField(pTyp, rData.sPar2, nsSwGetSetExpType::GSE_FORMULA, nFormatId);
+ pFld = new SwGetExpField(pTyp, rData.m_sPar2, nsSwGetSetExpType::GSE_FORMULA, nFormatId);
pFld->SetSubType(nSubType);
bExp = true;
}
@@ -1297,7 +1297,7 @@ bool SwFldMgr::InsertFld(
case TYP_SETREFPAGEFLD:
pFld = new SwRefPageSetField( static_cast<SwRefPageSetFieldType*>(
pCurShell->GetFldType( 0, RES_REFPAGESETFLD ) ),
- (short)rData.sPar2.toInt32(), 0 != nSubType );
+ (short)rData.m_sPar2.toInt32(), 0 != nSubType );
bPageVar = true;
break;
@@ -1309,13 +1309,13 @@ bool SwFldMgr::InsertFld(
case TYP_DROPDOWN :
{
pFld = new SwDropDownField(pCurShell->GetFldType( 0, RES_DROPDOWN ));
- const sal_Int32 nTokenCount = comphelper::string::getTokenCount(rData.sPar2, DB_DELIM);
+ const sal_Int32 nTokenCount = comphelper::string::getTokenCount(rData.m_sPar2, DB_DELIM);
Sequence<OUString> aEntries(nTokenCount);
OUString* pArray = aEntries.getArray();
for(sal_Int32 nToken = 0; nToken < nTokenCount; nToken++)
- pArray[nToken] = rData.sPar2.getToken(nToken, DB_DELIM);
+ pArray[nToken] = rData.m_sPar2.getToken(nToken, DB_DELIM);
static_cast<SwDropDownField*>(pFld)->SetItems(aEntries);
- static_cast<SwDropDownField*>(pFld)->SetName(rData.sPar1);
+ static_cast<SwDropDownField*>(pFld)->SetName(rData.m_sPar1);
}
break;
default:
@@ -1326,7 +1326,7 @@ bool SwFldMgr::InsertFld(
OSL_ENSURE(pFld, "field not available");
//the auto language flag has to be set prior to the language!
- pFld->SetAutomaticLanguage(rData.bIsAutomaticLanguage);
+ pFld->SetAutomaticLanguage(rData.m_bIsAutomaticLanguage);
sal_uInt16 nLang = GetCurrLanguage();
pFld->SetLanguage(nLang);
@@ -1346,7 +1346,7 @@ bool SwFldMgr::InsertFld(
}
else if( bPageVar )
static_cast<SwRefPageGetFieldType*>(pCurShell->GetFldType( 0, RES_REFPAGEGETFLD ))->UpdateFlds();
- else if( TYP_GETREFFLD == rData.nTypeId )
+ else if( TYP_GETREFFLD == rData.m_nTypeId )
pFld->GetTyp()->ModifyNotification( 0, 0 );
// delete temporary field